@@ -1,7 +1,12 @@
+from __future__ import absolute_import
 # Create your views here.
 
+from future import standard_library
+standard_library.install_aliases()
+from builtins import str
+from builtins import range
 from django.shortcuts import render_to_response
-from models import Schedule
+from .models import Schedule
 from django.http import HttpResponse,HttpResponseRedirect
 from datetime import date,datetime,timedelta,time
 import autoradio.autoradio_config
@@ -11,7 +16,7 @@ import autoradio.autompris2
 import os
 
 #from django.forms.extras.widgets import SelectDateWidget
-from widgets import MySelectDateWidget
+from .widgets import MySelectDateWidget
 from django.utils.translation import ugettext_lazy
 
 #----------------------------------------------------
@@ -35,11 +40,11 @@ def index(request):
 
 
 def stato(request):
-    import urllib2
+    import urllib.request, urllib.error, urllib.parse
         
     xmmsweb=""
     try:
-        url=urllib2.urlopen("http://"+autoradio.autoradio_config.XMMSHOST+":8888/")
+        url=urllib.request.urlopen("http://"+autoradio.autoradio_config.XMMSHOST+":8888/")
         for line in url:
             xmmsweb=xmmsweb+line
     except:
@@ -78,7 +83,7 @@ def dbusstato(request):
         htmlresponse+='<table border="1">'
         htmlresponse+='<td>position</td><td>lenght // remain</td><td>media</td>'
 
-        for pos in xrange(0,min(len,maxplele)):
+        for pos in range(0,min(len,maxplele)):
             htmlresponse+='<tr>'
             metadata=mp.get_metadata(pos)
 
@@ -201,10 +206,10 @@ def programsbook(request):
             PAGE_HEIGHT=defaultPageSize[1]
             styles = getSampleStyleSheet()
 
-            MezzoTrasmissione=Paragraph("Mezzo di diffusione: "+unicode(mezzo)+
-                                        "  //   Tipo di trasmissione: "+unicode(trasmissione), styles["Normal"])
-            EmittenteCanale=Paragraph("Denominazione dell'emittente: "+unicode(emittente)+
-                                      "  //   Denominazione del canale: "+unicode(canale), styles["Normal"])
+            MezzoTrasmissione=Paragraph("Mezzo di diffusione: "+str(mezzo)+
+                                        "  //   Tipo di trasmissione: "+str(trasmissione), styles["Normal"])
+            EmittenteCanale=Paragraph("Denominazione dell'emittente: "+str(emittente)+
+                                      "  //   Denominazione del canale: "+str(canale), styles["Normal"])
             Space=Spacer(inch, 0.25 * inch)
 
             # First the top row, with all the text centered and in Times-Bold,
@@ -254,7 +259,7 @@ def programsbook(request):
             Elements = [MezzoTrasmissione,EmittenteCanale,Space,Tabella]
 
             # Create the PDF object, using the response object as its "file."
-            p = SimpleDocTemplate(response,title="Libro programmi: "+unicode(emittente),author=author)
+            p = SimpleDocTemplate(response,title="Libro programmi: "+str(emittente),author=author)
             p.build(Elements, onFirstPage=myPages, onLaterPages=myPages)
 
 
